# pulp_maven_client

PulpMavenClient - the Ruby gem for the Pulp 3 API

Fetch, Upload, Organize, and Distribute Software Packages

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v3
- Package version: 0.3.1
- Build package: org.openapitools.codegen.languages.RubyClientCodegen
For more information, please visit [https://pulpproject.org](https://pulpproject.org)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build pulp_maven_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./pulp_maven_client-0.3.1.gem
```

(for development, run `gem install --dev ./pulp_maven_client-0.3.1.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'pulp_maven_client', '~> 0.3.1'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'pulp_maven_client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'pulp_maven_client'

# Setup authorization
PulpMavenClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR_USERNAME'
  config.password = 'YOUR_PASSWORD'
end

api_instance = PulpMavenClient::ContentArtifactApi.new
maven_maven_artifact = PulpMavenClient::MavenMavenArtifact.new # MavenMavenArtifact | 

begin
  #Create a maven artifact
  result = api_instance.create(maven_maven_artifact)
  p result
rescue PulpMavenClient::ApiError => e
  puts "Exception when calling ContentArtifactApi->create: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *http://pulp*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PulpMavenClient::ContentArtifactApi* | [**create**](docs/ContentArtifactApi.md#create) | **POST** /pulp/api/v3/content/maven/artifact/ | Create a maven artifact
*PulpMavenClient::ContentArtifactApi* | [**list**](docs/ContentArtifactApi.md#list) | **GET** /pulp/api/v3/content/maven/artifact/ | List maven artifacts
*PulpMavenClient::ContentArtifactApi* | [**read**](docs/ContentArtifactApi.md#read) | **GET** {maven_maven_artifact_href} | Inspect a maven artifact
*PulpMavenClient::DistributionsMavenApi* | [**create**](docs/DistributionsMavenApi.md#create) | **POST** /pulp/api/v3/distributions/maven/maven/ | Create a maven distribution
*PulpMavenClient::DistributionsMavenApi* | [**delete**](docs/DistributionsMavenApi.md#delete) | **DELETE** {maven_maven_distribution_href} | Delete a maven distribution
*PulpMavenClient::DistributionsMavenApi* | [**list**](docs/DistributionsMavenApi.md#list) | **GET** /pulp/api/v3/distributions/maven/maven/ | List maven distributions
*PulpMavenClient::DistributionsMavenApi* | [**partial_update**](docs/DistributionsMavenApi.md#partial_update) | **PATCH** {maven_maven_distribution_href} | Update a maven distribution
*PulpMavenClient::DistributionsMavenApi* | [**read**](docs/DistributionsMavenApi.md#read) | **GET** {maven_maven_distribution_href} | Inspect a maven distribution
*PulpMavenClient::DistributionsMavenApi* | [**update**](docs/DistributionsMavenApi.md#update) | **PUT** {maven_maven_distribution_href} | Update a maven distribution
*PulpMavenClient::RemotesMavenApi* | [**create**](docs/RemotesMavenApi.md#create) | **POST** /pulp/api/v3/remotes/maven/maven/ | Create a maven remote
*PulpMavenClient::RemotesMavenApi* | [**delete**](docs/RemotesMavenApi.md#delete) | **DELETE** {maven_maven_remote_href} | Delete a maven remote
*PulpMavenClient::RemotesMavenApi* | [**list**](docs/RemotesMavenApi.md#list) | **GET** /pulp/api/v3/remotes/maven/maven/ | List maven remotes
*PulpMavenClient::RemotesMavenApi* | [**partial_update**](docs/RemotesMavenApi.md#partial_update) | **PATCH** {maven_maven_remote_href} | Update a maven remote
*PulpMavenClient::RemotesMavenApi* | [**read**](docs/RemotesMavenApi.md#read) | **GET** {maven_maven_remote_href} | Inspect a maven remote
*PulpMavenClient::RemotesMavenApi* | [**update**](docs/RemotesMavenApi.md#update) | **PUT** {maven_maven_remote_href} | Update a maven remote
*PulpMavenClient::RepositoriesMavenApi* | [**create**](docs/RepositoriesMavenApi.md#create) | **POST** /pulp/api/v3/repositories/maven/maven/ | Create a maven repository
*PulpMavenClient::RepositoriesMavenApi* | [**delete**](docs/RepositoriesMavenApi.md#delete) | **DELETE** {maven_maven_repository_href} | Delete a maven repository
*PulpMavenClient::RepositoriesMavenApi* | [**list**](docs/RepositoriesMavenApi.md#list) | **GET** /pulp/api/v3/repositories/maven/maven/ | List maven repositorys
*PulpMavenClient::RepositoriesMavenApi* | [**partial_update**](docs/RepositoriesMavenApi.md#partial_update) | **PATCH** {maven_maven_repository_href} | Update a maven repository
*PulpMavenClient::RepositoriesMavenApi* | [**read**](docs/RepositoriesMavenApi.md#read) | **GET** {maven_maven_repository_href} | Inspect a maven repository
*PulpMavenClient::RepositoriesMavenApi* | [**update**](docs/RepositoriesMavenApi.md#update) | **PUT** {maven_maven_repository_href} | Update a maven repository
*PulpMavenClient::RepositoriesMavenVersionsApi* | [**delete**](docs/RepositoriesMavenVersionsApi.md#delete) | **DELETE** {maven_maven_repository_version_href} | Delete a repository version
*PulpMavenClient::RepositoriesMavenVersionsApi* | [**list**](docs/RepositoriesMavenVersionsApi.md#list) | **GET** {maven_maven_repository_href}versions/ | List repository versions
*PulpMavenClient::RepositoriesMavenVersionsApi* | [**read**](docs/RepositoriesMavenVersionsApi.md#read) | **GET** {maven_maven_repository_version_href} | Inspect a repository version
*PulpMavenClient::RepositoriesMavenVersionsApi* | [**repair**](docs/RepositoriesMavenVersionsApi.md#repair) | **POST** {maven_maven_repository_version_href}repair/ | 


## Documentation for Models

 - [PulpMavenClient::AsyncOperationResponse](docs/AsyncOperationResponse.md)
 - [PulpMavenClient::ContentSummary](docs/ContentSummary.md)
 - [PulpMavenClient::ContentSummaryResponse](docs/ContentSummaryResponse.md)
 - [PulpMavenClient::MavenMavenArtifact](docs/MavenMavenArtifact.md)
 - [PulpMavenClient::MavenMavenArtifactResponse](docs/MavenMavenArtifactResponse.md)
 - [PulpMavenClient::MavenMavenDistribution](docs/MavenMavenDistribution.md)
 - [PulpMavenClient::MavenMavenDistributionResponse](docs/MavenMavenDistributionResponse.md)
 - [PulpMavenClient::MavenMavenRemote](docs/MavenMavenRemote.md)
 - [PulpMavenClient::MavenMavenRemoteResponse](docs/MavenMavenRemoteResponse.md)
 - [PulpMavenClient::MavenMavenRepository](docs/MavenMavenRepository.md)
 - [PulpMavenClient::MavenMavenRepositoryResponse](docs/MavenMavenRepositoryResponse.md)
 - [PulpMavenClient::PaginatedRepositoryVersionResponseList](docs/PaginatedRepositoryVersionResponseList.md)
 - [PulpMavenClient::PaginatedmavenMavenArtifactResponseList](docs/PaginatedmavenMavenArtifactResponseList.md)
 - [PulpMavenClient::PaginatedmavenMavenDistributionResponseList](docs/PaginatedmavenMavenDistributionResponseList.md)
 - [PulpMavenClient::PaginatedmavenMavenRemoteResponseList](docs/PaginatedmavenMavenRemoteResponseList.md)
 - [PulpMavenClient::PaginatedmavenMavenRepositoryResponseList](docs/PaginatedmavenMavenRepositoryResponseList.md)
 - [PulpMavenClient::PatchedmavenMavenDistribution](docs/PatchedmavenMavenDistribution.md)
 - [PulpMavenClient::PatchedmavenMavenRemote](docs/PatchedmavenMavenRemote.md)
 - [PulpMavenClient::PatchedmavenMavenRepository](docs/PatchedmavenMavenRepository.md)
 - [PulpMavenClient::PolicyEnum](docs/PolicyEnum.md)
 - [PulpMavenClient::RepositoryVersion](docs/RepositoryVersion.md)
 - [PulpMavenClient::RepositoryVersionResponse](docs/RepositoryVersionResponse.md)


## Documentation for Authorization


### basicAuth

- **Type**: HTTP basic authentication

