# PulpMavenClient::ContentArtifactApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ContentArtifactApi.md#create) | **POST** /pulp/api/v3/content/maven/artifact/ | Create a maven artifact
[**list**](ContentArtifactApi.md#list) | **GET** /pulp/api/v3/content/maven/artifact/ | List maven artifacts
[**read**](ContentArtifactApi.md#read) | **GET** {maven_maven_artifact_href} | Inspect a maven artifact



## create

> MavenMavenArtifactResponse create(maven_maven_artifact)

Create a maven artifact

A ViewSet for MavenArtifact.

### Example

```ruby
# load the gem
require 'pulp_maven_client'
# setup authorization
PulpMavenClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpMavenClient::ContentArtifactApi.new
maven_maven_artifact = PulpMavenClient::MavenMavenArtifact.new # MavenMavenArtifact | 

begin
  #Create a maven artifact
  result = api_instance.create(maven_maven_artifact)
  p result
rescue PulpMavenClient::ApiError => e
  puts "Exception when calling ContentArtifactApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **maven_maven_artifact** | [**MavenMavenArtifact**](MavenMavenArtifact.md)|  | 

### Return type

[**MavenMavenArtifactResponse**](MavenMavenArtifactResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## list

> PaginatedmavenMavenArtifactResponseList list(opts)

List maven artifacts

A ViewSet for MavenArtifact.

### Example

```ruby
# load the gem
require 'pulp_maven_client'
# setup authorization
PulpMavenClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpMavenClient::ContentArtifactApi.new
opts = {
  artifact_id: 'artifact_id_example', # String | Filter results where artifact_id matches value
  filename: 'filename_example', # String | Filter results where filename matches value
  group_id: 'group_id_example', # String | Filter results where group_id matches value
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  version: 'version_example', # String | Filter results where version matches value
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List maven artifacts
  result = api_instance.list(opts)
  p result
rescue PulpMavenClient::ApiError => e
  puts "Exception when calling ContentArtifactApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **artifact_id** | **String**| Filter results where artifact_id matches value | [optional] 
 **filename** | **String**| Filter results where filename matches value | [optional] 
 **group_id** | **String**| Filter results where group_id matches value | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **version** | **String**| Filter results where version matches value | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedmavenMavenArtifactResponseList**](PaginatedmavenMavenArtifactResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> MavenMavenArtifactResponse read(maven_maven_artifact_href, opts)

Inspect a maven artifact

A ViewSet for MavenArtifact.

### Example

```ruby
# load the gem
require 'pulp_maven_client'
# setup authorization
PulpMavenClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpMavenClient::ContentArtifactApi.new
maven_maven_artifact_href = 'maven_maven_artifact_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a maven artifact
  result = api_instance.read(maven_maven_artifact_href, opts)
  p result
rescue PulpMavenClient::ApiError => e
  puts "Exception when calling ContentArtifactApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **maven_maven_artifact_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**MavenMavenArtifactResponse**](MavenMavenArtifactResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

