# PulpMavenClient::DistributionsMavenApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](DistributionsMavenApi.md#create) | **POST** /pulp/api/v3/distributions/maven/maven/ | Create a maven distribution
[**delete**](DistributionsMavenApi.md#delete) | **DELETE** {maven_maven_distribution_href} | Delete a maven distribution
[**list**](DistributionsMavenApi.md#list) | **GET** /pulp/api/v3/distributions/maven/maven/ | List maven distributions
[**partial_update**](DistributionsMavenApi.md#partial_update) | **PATCH** {maven_maven_distribution_href} | Update a maven distribution
[**read**](DistributionsMavenApi.md#read) | **GET** {maven_maven_distribution_href} | Inspect a maven distribution
[**update**](DistributionsMavenApi.md#update) | **PUT** {maven_maven_distribution_href} | Update a maven distribution



## create

> AsyncOperationResponse create(maven_maven_distribution)

Create a maven distribution

Trigger an asynchronous create task

### Example

```ruby
# load the gem
require 'pulp_maven_client'
# setup authorization
PulpMavenClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpMavenClient::DistributionsMavenApi.new
maven_maven_distribution = PulpMavenClient::MavenMavenDistribution.new # MavenMavenDistribution | 

begin
  #Create a maven distribution
  result = api_instance.create(maven_maven_distribution)
  p result
rescue PulpMavenClient::ApiError => e
  puts "Exception when calling DistributionsMavenApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **maven_maven_distribution** | [**MavenMavenDistribution**](MavenMavenDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(maven_maven_distribution_href)

Delete a maven distribution

Trigger an asynchronous delete task

### Example

```ruby
# load the gem
require 'pulp_maven_client'
# setup authorization
PulpMavenClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpMavenClient::DistributionsMavenApi.new
maven_maven_distribution_href = 'maven_maven_distribution_href_example' # String | 

begin
  #Delete a maven distribution
  result = api_instance.delete(maven_maven_distribution_href)
  p result
rescue PulpMavenClient::ApiError => e
  puts "Exception when calling DistributionsMavenApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **maven_maven_distribution_href** | **String**|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list

> PaginatedmavenMavenDistributionResponseList list(opts)

List maven distributions

ViewSet for Maven Distributions.

### Example

```ruby
# load the gem
require 'pulp_maven_client'
# setup authorization
PulpMavenClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpMavenClient::DistributionsMavenApi.new
opts = {
  base_path: 'base_path_example', # String | 
  base_path__contains: 'base_path__contains_example', # String | Filter results where base_path contains value
  base_path__icontains: 'base_path__icontains_example', # String | Filter results where base_path contains value
  base_path__in: ['base_path__in_example'], # Array<String> | Filter results where base_path is in a comma-separated list of values
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | 
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  pulp_label_select: 'pulp_label_select_example', # String | Filter labels by search string
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List maven distributions
  result = api_instance.list(opts)
  p result
rescue PulpMavenClient::ApiError => e
  puts "Exception when calling DistributionsMavenApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **base_path** | **String**|  | [optional] 
 **base_path__contains** | **String**| Filter results where base_path contains value | [optional] 
 **base_path__icontains** | **String**| Filter results where base_path contains value | [optional] 
 **base_path__in** | [**Array&lt;String&gt;**](String.md)| Filter results where base_path is in a comma-separated list of values | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**|  | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **pulp_label_select** | **String**| Filter labels by search string | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedmavenMavenDistributionResponseList**](PaginatedmavenMavenDistributionResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(maven_maven_distribution_href, patchedmaven_maven_distribution)

Update a maven distribution

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulp_maven_client'
# setup authorization
PulpMavenClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpMavenClient::DistributionsMavenApi.new
maven_maven_distribution_href = 'maven_maven_distribution_href_example' # String | 
patchedmaven_maven_distribution = PulpMavenClient::PatchedmavenMavenDistribution.new # PatchedmavenMavenDistribution | 

begin
  #Update a maven distribution
  result = api_instance.partial_update(maven_maven_distribution_href, patchedmaven_maven_distribution)
  p result
rescue PulpMavenClient::ApiError => e
  puts "Exception when calling DistributionsMavenApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **maven_maven_distribution_href** | **String**|  | 
 **patchedmaven_maven_distribution** | [**PatchedmavenMavenDistribution**](PatchedmavenMavenDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> MavenMavenDistributionResponse read(maven_maven_distribution_href, opts)

Inspect a maven distribution

ViewSet for Maven Distributions.

### Example

```ruby
# load the gem
require 'pulp_maven_client'
# setup authorization
PulpMavenClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpMavenClient::DistributionsMavenApi.new
maven_maven_distribution_href = 'maven_maven_distribution_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a maven distribution
  result = api_instance.read(maven_maven_distribution_href, opts)
  p result
rescue PulpMavenClient::ApiError => e
  puts "Exception when calling DistributionsMavenApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **maven_maven_distribution_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**MavenMavenDistributionResponse**](MavenMavenDistributionResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update

> AsyncOperationResponse update(maven_maven_distribution_href, maven_maven_distribution)

Update a maven distribution

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulp_maven_client'
# setup authorization
PulpMavenClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpMavenClient::DistributionsMavenApi.new
maven_maven_distribution_href = 'maven_maven_distribution_href_example' # String | 
maven_maven_distribution = PulpMavenClient::MavenMavenDistribution.new # MavenMavenDistribution | 

begin
  #Update a maven distribution
  result = api_instance.update(maven_maven_distribution_href, maven_maven_distribution)
  p result
rescue PulpMavenClient::ApiError => e
  puts "Exception when calling DistributionsMavenApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **maven_maven_distribution_href** | **String**|  | 
 **maven_maven_distribution** | [**MavenMavenDistribution**](MavenMavenDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

