# PulpMavenClient::RemotesMavenApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](RemotesMavenApi.md#create) | **POST** /pulp/api/v3/remotes/maven/maven/ | Create a maven remote
[**delete**](RemotesMavenApi.md#delete) | **DELETE** {maven_maven_remote_href} | Delete a maven remote
[**list**](RemotesMavenApi.md#list) | **GET** /pulp/api/v3/remotes/maven/maven/ | List maven remotes
[**partial_update**](RemotesMavenApi.md#partial_update) | **PATCH** {maven_maven_remote_href} | Update a maven remote
[**read**](RemotesMavenApi.md#read) | **GET** {maven_maven_remote_href} | Inspect a maven remote
[**update**](RemotesMavenApi.md#update) | **PUT** {maven_maven_remote_href} | Update a maven remote



## create

> MavenMavenRemoteResponse create(maven_maven_remote)

Create a maven remote

A ViewSet for MavenRemote.

### Example

```ruby
# load the gem
require 'pulp_maven_client'
# setup authorization
PulpMavenClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpMavenClient::RemotesMavenApi.new
maven_maven_remote = PulpMavenClient::MavenMavenRemote.new # MavenMavenRemote | 

begin
  #Create a maven remote
  result = api_instance.create(maven_maven_remote)
  p result
rescue PulpMavenClient::ApiError => e
  puts "Exception when calling RemotesMavenApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **maven_maven_remote** | [**MavenMavenRemote**](MavenMavenRemote.md)|  | 

### Return type

[**MavenMavenRemoteResponse**](MavenMavenRemoteResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(maven_maven_remote_href)

Delete a maven remote

Trigger an asynchronous delete task

### Example

```ruby
# load the gem
require 'pulp_maven_client'
# setup authorization
PulpMavenClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpMavenClient::RemotesMavenApi.new
maven_maven_remote_href = 'maven_maven_remote_href_example' # String | 

begin
  #Delete a maven remote
  result = api_instance.delete(maven_maven_remote_href)
  p result
rescue PulpMavenClient::ApiError => e
  puts "Exception when calling RemotesMavenApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **maven_maven_remote_href** | **String**|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list

> PaginatedmavenMavenRemoteResponseList list(opts)

List maven remotes

A ViewSet for MavenRemote.

### Example

```ruby
# load the gem
require 'pulp_maven_client'
# setup authorization
PulpMavenClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpMavenClient::RemotesMavenApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | 
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  pulp_label_select: 'pulp_label_select_example', # String | Filter labels by search string
  pulp_last_updated: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | ISO 8601 formatted dates are supported
  pulp_last_updated__gt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is greater than value
  pulp_last_updated__gte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is greater than or equal to value
  pulp_last_updated__lt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is less than value
  pulp_last_updated__lte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is less than or equal to value
  pulp_last_updated__range: [DateTime.parse('2013-10-20T19:20:30+01:00')], # Array<DateTime> | Filter results where pulp_last_updated is between two comma separated values
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List maven remotes
  result = api_instance.list(opts)
  p result
rescue PulpMavenClient::ApiError => e
  puts "Exception when calling RemotesMavenApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**|  | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **pulp_label_select** | **String**| Filter labels by search string | [optional] 
 **pulp_last_updated** | **DateTime**| ISO 8601 formatted dates are supported | [optional] 
 **pulp_last_updated__gt** | **DateTime**| Filter results where pulp_last_updated is greater than value | [optional] 
 **pulp_last_updated__gte** | **DateTime**| Filter results where pulp_last_updated is greater than or equal to value | [optional] 
 **pulp_last_updated__lt** | **DateTime**| Filter results where pulp_last_updated is less than value | [optional] 
 **pulp_last_updated__lte** | **DateTime**| Filter results where pulp_last_updated is less than or equal to value | [optional] 
 **pulp_last_updated__range** | [**Array&lt;DateTime&gt;**](DateTime.md)| Filter results where pulp_last_updated is between two comma separated values | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedmavenMavenRemoteResponseList**](PaginatedmavenMavenRemoteResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(maven_maven_remote_href, patchedmaven_maven_remote)

Update a maven remote

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulp_maven_client'
# setup authorization
PulpMavenClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpMavenClient::RemotesMavenApi.new
maven_maven_remote_href = 'maven_maven_remote_href_example' # String | 
patchedmaven_maven_remote = PulpMavenClient::PatchedmavenMavenRemote.new # PatchedmavenMavenRemote | 

begin
  #Update a maven remote
  result = api_instance.partial_update(maven_maven_remote_href, patchedmaven_maven_remote)
  p result
rescue PulpMavenClient::ApiError => e
  puts "Exception when calling RemotesMavenApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **maven_maven_remote_href** | **String**|  | 
 **patchedmaven_maven_remote** | [**PatchedmavenMavenRemote**](PatchedmavenMavenRemote.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> MavenMavenRemoteResponse read(maven_maven_remote_href, opts)

Inspect a maven remote

A ViewSet for MavenRemote.

### Example

```ruby
# load the gem
require 'pulp_maven_client'
# setup authorization
PulpMavenClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpMavenClient::RemotesMavenApi.new
maven_maven_remote_href = 'maven_maven_remote_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a maven remote
  result = api_instance.read(maven_maven_remote_href, opts)
  p result
rescue PulpMavenClient::ApiError => e
  puts "Exception when calling RemotesMavenApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **maven_maven_remote_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**MavenMavenRemoteResponse**](MavenMavenRemoteResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update

> AsyncOperationResponse update(maven_maven_remote_href, maven_maven_remote)

Update a maven remote

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulp_maven_client'
# setup authorization
PulpMavenClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpMavenClient::RemotesMavenApi.new
maven_maven_remote_href = 'maven_maven_remote_href_example' # String | 
maven_maven_remote = PulpMavenClient::MavenMavenRemote.new # MavenMavenRemote | 

begin
  #Update a maven remote
  result = api_instance.update(maven_maven_remote_href, maven_maven_remote)
  p result
rescue PulpMavenClient::ApiError => e
  puts "Exception when calling RemotesMavenApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **maven_maven_remote_href** | **String**|  | 
 **maven_maven_remote** | [**MavenMavenRemote**](MavenMavenRemote.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

